@@ -1,3 +1,4 @@
+use std::collections::BTreeMap;
 use std::sync::Arc;
 
 use futures_util::stream::{Stream, select_all};
@@ -697,34 +698,59 @@ impl ConsumerConfigBuilder {
     }
 
     /// Adds a SmartStream filter to this ConsumerConfig
-    pub fn wasm_filter<T: Into<Vec<u8>>>(&mut self, filter: T) -> &mut Self {
+    pub fn wasm_filter<T: Into<Vec<u8>>>(
+        &mut self,
+        filter: T,
+        params: BTreeMap<String, String>,
+    ) -> &mut Self {
         self.wasm_module(SmartStreamPayload {
             wasm: SmartStreamWasm::Raw(filter.into()),
             kind: SmartStreamKind::Filter,
+            params: params.into(),
         });
         self
     }
 
     /// Adds a SmartStream map to this ConsumerConfig
-    pub fn wasm_map<T: Into<Vec<u8>>>(&mut self, map: T) -> &mut Self {
+    pub fn wasm_map<T: Into<Vec<u8>>>(
+        &mut self,
+        map: T,
+        params: BTreeMap<String, String>,
+    ) -> &mut Self {
         self.wasm_module(SmartStreamPayload {
             wasm: SmartStreamWasm::Raw(map.into()),
             kind: SmartStreamKind::Map,
+            params: params.into(),
         });
         self
     }
 
+    /// Adds a SmartStream array_map to this ConsumerConfig
+    pub fn wasm_array_map<T: Into<Vec<u8>>>(
+        &mut self,
+        array_map: T,
+        params: BTreeMap<String, String>,
+    ) -> &mut Self {
+        self.wasm_module(SmartStreamPayload {
+            wasm: SmartStreamWasm::Raw(array_map.into()),
+            kind: SmartStreamKind::ArrayMap,
+            params: params.into(),
+        })
+    }
+
     /// Set a WASM aggregator function and initial accumulator value
     pub fn wasm_aggregate<T: Into<Vec<u8>>, U: Into<Vec<u8>>>(
         &mut self,
         aggregate: T,
         accumulator: U,
+        params: BTreeMap<String, String>,
     ) -> &mut Self {
         self.wasm_module(SmartStreamPayload {
             wasm: SmartStreamWasm::Raw(aggregate.into()),
             kind: SmartStreamKind::Aggregate {
                 accumulator: accumulator.into(),
             },
+            params: params.into(),
         });
         self
     }
