@@ -5,6 +5,7 @@ use fluvio_sc_schema::ApiError;
 use crate::config::ConfigError;
 use semver::Version;
 use dataplane::smartstream::SmartStreamRuntimeError;
+use dataplane::SmartStreamError;
 
 /// Possible errors that may arise when using Fluvio
 #[derive(thiserror::Error, Debug)]
@@ -17,7 +18,7 @@ pub enum FluvioError {
     PartitionNotFound(String, i32),
     #[error("Spu not found: {0}")]
     SPUNotFound(i32),
-    #[error("Fluvio socket error: {0}")]
+    #[error("Fluvio socket error")]
     Socket(#[from] SocketError),
     #[error("Fluvio controlplane error: {0}")]
     AdminApi(#[from] ApiError),
@@ -43,8 +44,11 @@ To interact with this cluster, please install the matching CLI version using the
     },
     #[error("Consumer config error: {0}")]
     ConsumerConfig(String),
+    #[deprecated(since = "0.9.8", note = "use 'FluvioError::SmartStream' instead")]
     #[error("Encountered a runtime error in the user's SmartStream: {0}")]
     SmartStreamRuntime(#[from] SmartStreamRuntimeError),
+    #[error("SmartStream error")]
+    SmartStream(#[from] SmartStreamError),
     #[error("Unknown error: {0}")]
     Other(String),
 }
