@@ -208,6 +208,9 @@ pub mod metadata {
         pub use fluvio_sc_schema::connector::*;
     }
 
+    pub mod smartmodule {
+        pub use fluvio_sc_schema::smartmodule::*;
+    }
     pub mod spu {
         pub use fluvio_sc_schema::spu::*;
     }
